@@ -92,8 +92,8 @@ class util(object):
 		''' clec.spacybs -> clec.sqlite, 2022.2.27 '''
 		if not outfile : outfile  = dbfile.split('.')[0] + ".sqlite" 
 		print (f"[index] started, {dbfile} -> {outfile}", flush=True)
-		conn = init_db(outfile)
-		ssi = defaultdict(Counter) #si = Counter()
+		if fts: conn = init_db(outfile)
+		ssi = defaultdict(Counter) 
 		for rowid, snt, bs in tqdm(Spacybs(dbfile).items()) :
 			try:
 				doc = frombs(bs)
@@ -101,11 +101,38 @@ class util(object):
 				if fts: doc_fts(conn, rowid, snt, doc) 
 			except Exception as e:
 				print ("ex:", e, rowid, snt)
-		conn.commit()
+		if fts: conn.commit()
 		print (f"start to dump ssi, {dbfile} -> {outfile}")
 		submit_ssi(outfile, ssi)
 		print (f"[index] finished, {dbfile} -> {outfile}")
 
+	def indexdoc(self,dbfile, sql="select id, doc_txt from doc", ssi=False):  
+		''' spider_docs.sqlit3, 2022.3.11 '''
+		print (f"[indexdoc] started, {dbfile} ", flush=True)
+		conn = sqlite3.connect(dbfile, check_same_thread=False)  
+		conn.execute(f'DROP TABLE IF EXISTS fts')
+		conn.execute('''CREATE VIRTUAL TABLE if not exists fts USING fts5(sid, snt, terms, columnsize=0, detail=full,tokenize = "unicode61 remove_diacritics 0 tokenchars '-_'")''') #self.conn.execute('''CREATE VIRTUAL TABLE if not exists fts USING fts5(snt, terms, columnsize=0, detail=none,tokenize = "unicode61 remove_diacritics 0 tokenchars '-_'")''')
+		conn.execute('PRAGMA synchronous=OFF')
+		conn.commit()
+		db = Spacybs(dbfile + ".spacybs")
+		ssi = defaultdict(Counter) #si = Counter()
+		for row in conn.execute(sql).fetchall(): 
+			try:
+				did		= row[0]
+				essay	= row[1]
+				for i,snt in enumerate(snts(essay) ): 
+					doc = nlp(snt) #frombs(bs)
+					if snt and not snt in db: db[snt] = tobs(nlp(snt))
+					conn.execute(f"insert or ignore into fts(sid, snt,terms) values(?,?,?)", (f"{did}-{i}", snt, " ".join([ f"{t.pos_}_{t.lemma_}" for t in doc] + [ f"{t.tag_}_{t.lemma_}" for t in doc] + [ f"{t.dep_}_{t.head.pos_}_{t.pos_}_{t.head.lemma_}_{t.lemma_}" for t in doc if t.pos_ not in ('PRON','PUNCT') and t.dep_ in ('dobj','nsubj','advmod','acomp','amod','compound','xcomp','ccomp')]) ))
+					if ssi: terms.zset_ssi(doc, ssi)
+			except Exception as e:
+				print ("ex:", e, rowid, snt)
+		conn.commit()
+		db.close()
+		print (f"start to dump ssi, {dbfile}")
+		if ssi: submit_ssi(dbfile, ssi)
+		print (f"[indexdoc] finished, {dbfile}")
+
 	def si(self,dbfile, outfile):  
 		''' clec.spacybs -> add si, 2022.2.26 '''
 		si = Counter()
