@@ -341,7 +341,7 @@ def zset_ssi(doc, ssi):  # ssi = defaultdict(Counter)
 			  (f"{t.lemma_}/{t.pos_}", f"~{t.dep_}"), # door/NOUN :  ~dobj
 			  (f"*/{t.head.pos_}", f"{t.dep_}"),  # */VERB  : dobj
 			  (f"*/{t.pos_}", f"~{t.dep_}"), # */NOUN :  ~dobj
-			) for t in doc if t.dep_ not in ('ROOT','punct') and t.pos_ not in ('PUNCT','SPACE')] 
+			) for t in doc if t.dep_ not in ('punct') and t.pos_ not in ('PUNCT','SPACE',"PROPN","NUM") and t.text.isalpha()]  #'ROOT',
 	[ hit(ssi,  (f"{t.lemma_}/VERB", "rootv"), (f"*/VERB", "rootv") )  for t in doc if t.dep_ =='ROOT' and t.pos_ == 'VERB']
 	[ hit(ssi,  (f"vvbg", f"{t.head.lemma_} {t.text.lower()}"), 
 				(f"{t.head.lemma_}/VERB", "vvbg"), 
@@ -357,7 +357,7 @@ def zset_ssi(doc, ssi):  # ssi = defaultdict(Counter)
 				(f"*/VERB", "mdv"), 
 				) for t in doc  if t.tag_ == 'MD' and t.dep_ =='aux' and t.head.pos_ == 'VERB' and t.head.lemma_.isalpha()]
 
-	[ ( n:=sp.root.lemma_.lower(), np:= sp.text.lower(), 
+	[ ( n:=sp.root.lemma_.lower(), np:= sp.text.lower(), # book/np:a book
 		hit(ssi, (f"{n}/np", np), (f"{n}/NOUN", "np"), (f"*/NOUN", "np"), ) ) for sp in doc.noun_chunks if sp.end - sp.start > 1] # add  #book:np , f"#{sp.root.lemma_.lower()}:np" 
 	[ ( n:=sp.root.lemma_.lower(), np:= sp.text.lower(), 
 		hit(ssi, (f"{n}/npone", np), (f"{n}/NOUN", "npone"), (f"*/NOUN", "npone"), )) for sp in doc.noun_chunks  if sp.end - sp.start <= 1]
