@@ -141,10 +141,10 @@ class ES(object):
 	def init(self, idxname):
 		''' init a new index '''
 		try:
-			if self.es.indices.exists(idxname):
+			if self.es.indices.exists(index=idxname):
 				print("already exists", idxname)
-				self.es.indices.delete(idxname)
-			self.es.indices.create(idxname, config) #, body=snt_mapping
+				self.es.indices.delete(index=idxname)
+			self.es.indices.create(index=idxname, body=config) #, body=snt_mapping
 		except Exception as e:
 			print("exception,", str(e))
 		print(">>finished " + idxname )
