@@ -84,11 +84,13 @@ class util(object):
 		uvicorn.run(app, host='0.0.0.0', port=wwwport)
 
 from uvirun import *
-inst = util()
 @app.get('/annotate/tagdoc')
-def annotate_tagdoc(did:str="101"):  
+def annotate(did:str="101", rhost:str='127.0.0.1', rport:int=9221, rdb=0):  
 	'''  ''' 
-	inst.tag(did) 
+	if not hasattr(annotate, 'inst'):
+		annotate.inst = util(host=rhost, port=rport, db=rdb)
+	annotate.inst.tag(did) 
+	return did 
 	
 if __name__ == "__main__":  
 	fire.Fire(util)
\ No newline at end of file
