@@ -22,6 +22,12 @@ def nlp_sntbr(text:str="The quick fox jumped over the lazy dog. The justice dela
 	'''  '''
 	return snts(text, trim) 
 
+@app.post("/nlp/wordidf")
+def nlp_wordidf(words:list=["niche","dilemma","consider","consider**"], default_idf:float=0):
+	'''  '''
+	from dic.word_idf import word_idf 
+	return  { w: word_idf.get(w, default_idf) for w in words}
+
 def run(port):
 	uvicorn.run(app, host='0.0.0.0', port=port)
 
